@@ -6,7 +6,7 @@ import json
 from pathlib import Path
 
 from .lockfile import Lockfile
-from .requirements import RequirementSpec, parse_requirements_file, parse_requirements_from_python_script
+from .requirements import RequirementSpec, parse_requirements_from_python_script
 
 
 class ProjectInterface(abc.ABC):
@@ -29,12 +29,10 @@ class DefaultProjectImpl(ProjectInterface):
     Buildscript requirements are looked up in the `.kraken.py` header if prefixed with the string `# ::requirements`.
     Lockfiles are written to a file named `.kraken.lock`."""
 
-    REQUIREMENT_FILES = [Path(".kraken/requirements.txt"), Path(".kraken.requirements")]
-    LOCK_FILES = [Path(".kraken/kraken.lock"), Path(".kraken.lock")]
+    LOCK_FILES = [Path(".kraken.lock")]
 
     @dataclasses.dataclass
     class Files:
-        requirements: Path | None
         script: Path | None
         lock: Path
 
@@ -52,22 +50,13 @@ class DefaultProjectImpl(ProjectInterface):
             return self._files
 
         # Find a file we can load requirements from.
-        requirements_file: Path | None = None
         script_file: Path | None = None
-        for path in self.REQUIREMENT_FILES:
-            requirements_file = self.project_dir / path
-            if requirements_file.is_file():
+        for loader in get_loader_implementations():
+            script_file = loader.detect_in_project_directory(self.project_dir)
+            if script_file:
                 break
-        else:
-            requirements_file = None
-            for loader in get_loader_implementations():
-                script_file = loader.detect_in_project_directory(self.project_dir)
-                if script_file:
-                    break
-            else:
-                raise RuntimeError("could not find a requirements file or Kraken build script")
-
-        assert requirements_file or script_file
+        if not script_file:
+            raise RuntimeError("no Kraken build script found")
 
         # Find the lock file.
         alternative_lock_file: Path | None = None
@@ -81,17 +70,14 @@ class DefaultProjectImpl(ProjectInterface):
             assert alternative_lock_file
             lock_file = alternative_lock_file
 
-        self._files = self.Files(requirements_file, script_file, lock_file)
+        self._files = self.Files(script_file, lock_file)
         return self._files
 
     def get_requirement_spec(self) -> RequirementSpec:
         files = self._get_files()
-        if files.requirements:
-            with files.requirements.open() as fp:
-                requirements = RequirementSpec.from_args(parse_requirements_file(fp))
-        elif files.script:
+        if files.script:
             with files.script.open() as fp:
-                requirements = RequirementSpec.from_args(parse_requirements_from_python_script(fp))
+                requirements = parse_requirements_from_python_script(fp)
         else:
             assert False, files
         requirements.add_requirements(self._implied_requirements)
